##  Overview
The Gartner® TIME framework is one of the key methodologies used in SAP LeanIX to evaluate an organization’s application portfolio. It is recommended to apply TIME from the beginning, right from when you realize your first use case with SAP LeanIX ([Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.")), but also as a common practice in other use cases such as [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach."). This page summarizes what TIME classification is, how it is embedded into SAP LeanIX, and how we recommend using it as part of your enterprise architecture work in SAP LeanIX.
Check also our other key methodologies, such as [6R](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) and [Pace Layering](https://help.sap.com/docs/leanix/ea/pace-layering?locale=en-US&state=PRODUCTION&version=CLOUD), to further enhance your enterprise architecture practices with SAP LeanIX.
